# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.healthcheck.v1beta import healthcheck_pb2 as common_dot_healthcheck_dot_v1beta_dot_healthcheck__pb2
from common.task.v1alpha import task_pb2 as common_dot_task_dot_v1alpha_dot_task__pb2
from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from model.model.v1alpha import common_pb2 as model_dot_model_dot_v1alpha_dot_common__pb2
from model.model.v1alpha import model_definition_pb2 as model_dot_model_dot_v1alpha_dot_model__definition__pb2
from model.model.v1alpha import task_classification_pb2 as model_dot_model_dot_v1alpha_dot_task__classification__pb2
from model.model.v1alpha import task_detection_pb2 as model_dot_model_dot_v1alpha_dot_task__detection__pb2
from model.model.v1alpha import task_image_to_image_pb2 as model_dot_model_dot_v1alpha_dot_task__image__to__image__pb2
from model.model.v1alpha import task_instance_segmentation_pb2 as model_dot_model_dot_v1alpha_dot_task__instance__segmentation__pb2
from model.model.v1alpha import task_keypoint_pb2 as model_dot_model_dot_v1alpha_dot_task__keypoint__pb2
from model.model.v1alpha import task_ocr_pb2 as model_dot_model_dot_v1alpha_dot_task__ocr__pb2
from model.model.v1alpha import task_semantic_segmentation_pb2 as model_dot_model_dot_v1alpha_dot_task__semantic__segmentation__pb2
from model.model.v1alpha import task_text_generation_pb2 as model_dot_model_dot_v1alpha_dot_task__text__generation__pb2
from model.model.v1alpha import task_text_generation_chat_pb2 as model_dot_model_dot_v1alpha_dot_task__text__generation__chat__pb2
from model.model.v1alpha import task_text_to_image_pb2 as model_dot_model_dot_v1alpha_dot_task__text__to__image__pb2
from model.model.v1alpha import task_unspecified_pb2 as model_dot_model_dot_v1alpha_dot_task__unspecified__pb2
from model.model.v1alpha import task_visual_question_answering_pb2 as model_dot_model_dot_v1alpha_dot_task__visual__question__answering__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fmodel/model/v1alpha/model.proto\x12\x13model.model.v1alpha\x1a+common/healthcheck/v1beta/healthcheck.proto\x1a\x1e\x63ommon/task/v1alpha/task.proto\x1a\x1b\x63ore/mgmt/v1beta/mgmt.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a#google/longrunning/operations.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a model/model/v1alpha/common.proto\x1a*model/model/v1alpha/model_definition.proto\x1a-model/model/v1alpha/task_classification.proto\x1a(model/model/v1alpha/task_detection.proto\x1a-model/model/v1alpha/task_image_to_image.proto\x1a\x34model/model/v1alpha/task_instance_segmentation.proto\x1a\'model/model/v1alpha/task_keypoint.proto\x1a\"model/model/v1alpha/task_ocr.proto\x1a\x34model/model/v1alpha/task_semantic_segmentation.proto\x1a.model/model/v1alpha/task_text_generation.proto\x1a\x33model/model/v1alpha/task_text_generation_chat.proto\x1a,model/model/v1alpha/task_text_to_image.proto\x1a*model/model/v1alpha/task_unspecified.proto\x1a\x38model/model/v1alpha/task_visual_question_answering.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\x96\x01\n\x0fLivenessRequest\x12j\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x04\xe2\x41\x01\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"v\n\x10LivenessResponse\x12\x62\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseR\x13healthCheckResponse\"\x97\x01\n\x10ReadinessRequest\x12j\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x04\xe2\x41\x01\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"w\n\x11ReadinessResponse\x12\x62\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseR\x13healthCheckResponse\"E\n\x06Region\x12\x1f\n\x0bregion_name\x18\x01 \x01(\tR\nregionName\x12\x1a\n\x08hardware\x18\x02 \x03(\tR\x08hardware\"\xe2\x01\n\x0cModelVersion\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x05R\x04name\x12\x1e\n\x07version\x18\x02 \x01(\tB\x04\xe2\x41\x01\x05R\x07version\x12\x1c\n\x06\x64igest\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\x06\x64igest\x12\x36\n\x05state\x18\x04 \x01(\x0e\x32\x1a.model.model.v1alpha.StateB\x04\xe2\x41\x01\x03R\x05state\x12\x42\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x01R\nupdateTime\"\xb3\r\n\x05Model\x12+\n\x04name\x18\x01 \x01(\tB\x17\x92\x41\x10\xca>\r\xfa\x02\nmodel_name\xe2\x41\x01\x03R\x04name\x12\x16\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12\x15\n\x02id\x18\x03 \x01(\tB\x05\xe2\x41\x02\x02\x05R\x02id\x12+\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x00R\x0b\x64\x65scription\x88\x01\x01\x12U\n\x10model_definition\x18\x05 \x01(\tB*\xe2\x41\x02\x02\x05\xfa\x41\"\n api.instill.tech/ModelDefinitionR\x0fmodelDefinition\x12\x44\n\rconfiguration\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructB\x05\xe2\x41\x02\x02\x05R\rconfiguration\x12\x34\n\x04task\x18\x07 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x05\xe2\x41\x02\x02\x05R\x04task\x12K\n\nvisibility\x18\t \x01(\x0e\x32%.model.model.v1alpha.Model.VisibilityB\x04\xe2\x41\x01\x02R\nvisibility\x12\x41\n\x0b\x63reate_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x41\n\x0bupdate_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\nupdateTime\x12\x41\n\x0b\x64\x65lete_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ndeleteTime\x12#\n\nowner_name\x18\x0f \x01(\tB\x04\xe2\x41\x01\x03R\townerName\x12\x39\n\x05owner\x18\x11 \x01(\x0b\x32\x17.core.mgmt.v1beta.OwnerB\x05\xe2\x41\x02\x01\x03H\x01R\x05owner\x88\x01\x01\x12\x1d\n\x06region\x18\x12 \x01(\tB\x05\xe2\x41\x02\x02\x05R\x06region\x12 \n\x08hardware\x18\x13 \x01(\tB\x04\xe2\x41\x01\x02R\x08hardware\x12!\n\x06readme\x18\x14 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06readme\x88\x01\x01\x12(\n\nsource_url\x18\x15 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\tsourceUrl\x88\x01\x01\x12\x36\n\x11\x64ocumentation_url\x18\x16 \x01(\tB\x04\xe2\x41\x01\x01H\x04R\x10\x64ocumentationUrl\x88\x01\x01\x12#\n\x07license\x18\x17 \x01(\tB\x04\xe2\x41\x01\x01H\x05R\x07license\x88\x01\x01\x12G\n\x0csample_input\x18\x18 \x01(\x0b\x32\x1e.model.model.v1alpha.TaskInputB\x04\xe2\x41\x01\x03R\x0bsampleInput\x12J\n\rsample_output\x18\x19 \x01(\x0b\x32\x1f.model.model.v1alpha.TaskOutputB\x04\xe2\x41\x01\x03R\x0csampleOutput\x12.\n\rprofile_image\x18\x1a \x01(\tB\x04\xe2\x41\x01\x01H\x06R\x0cprofileImage\x88\x01\x01\x12\x45\n\npermission\x18\x1b \x01(\x0b\x32\x1f.model.model.v1alpha.PermissionB\x04\xe2\x41\x01\x03R\npermission\x12@\n\x0cinput_schema\x18\x1c \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x03R\x0binputSchema\x12\x42\n\routput_schema\x18\x1d \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x03R\x0coutputSchema\x12\x18\n\x04tags\x18\x1e \x03(\tB\x04\xe2\x41\x01\x03R\x04tags\x12 \n\x08versions\x18\x1f \x03(\tB\x04\xe2\x41\x01\x03R\x08versions\"W\n\nVisibility\x12\x1a\n\x16VISIBILITY_UNSPECIFIED\x10\x00\x12\x16\n\x12VISIBILITY_PRIVATE\x10\x01\x12\x15\n\x11VISIBILITY_PUBLIC\x10\x02:R\xea\x41O\n\x16\x61pi.instill.tech/Model\x12!users/{user.id}/models/{model.id}\x12\x12models/{model.uid}B\x0e\n\x0c_descriptionB\x08\n\x06_ownerB\t\n\x07_readmeB\r\n\x0b_source_urlB\x14\n\x12_documentation_urlB\n\n\x08_licenseB\x10\n\x0e_profile_imageJ\x04\x08\x08\x10\tJ\x04\x08\x10\x10\x11\"\xc6\x03\n\x11ListModelsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x38\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12,\n\x0cshow_deleted\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x03R\x0bshowDeleted\x88\x01\x01\x12!\n\x06\x66ilter\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01H\x04R\x06\x66ilter\x88\x01\x01\x12P\n\nvisibility\x18\x06 \x01(\x0e\x32%.model.model.v1alpha.Model.VisibilityB\x04\xe2\x41\x01\x01H\x05R\nvisibility\x88\x01\x01\x12$\n\x08order_by\x18\x07 \x01(\tB\x04\xe2\x41\x01\x01H\x06R\x07orderBy\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\x0f\n\r_show_deletedB\t\n\x07_filterB\r\n\x0b_visibilityB\x0b\n\t_order_by\"\x8f\x01\n\x12ListModelsResponse\x12\x32\n\x06models\x18\x01 \x03(\x0b\x32\x1a.model.model.v1alpha.ModelR\x06models\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"{\n\x12LookUpModelRequest\x12\"\n\tpermalink\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\tpermalink\x12\x38\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"G\n\x13LookUpModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"\xf8\x03\n\x1aListNamespaceModelsRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12&\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x38\n\x04view\x18\x04 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12,\n\x0cshow_deleted\x18\x05 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x03R\x0bshowDeleted\x88\x01\x01\x12!\n\x06\x66ilter\x18\x06 \x01(\tB\x04\xe2\x41\x01\x01H\x04R\x06\x66ilter\x88\x01\x01\x12P\n\nvisibility\x18\x07 \x01(\x0e\x32%.model.model.v1alpha.Model.VisibilityB\x04\xe2\x41\x01\x01H\x05R\nvisibility\x88\x01\x01\x12$\n\x08order_by\x18\x08 \x01(\tB\x04\xe2\x41\x01\x01H\x06R\x07orderBy\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\x0f\n\r_show_deletedB\t\n\x07_filterB\r\n\x0b_visibilityB\x0b\n\t_order_by\"\x98\x01\n\x1bListNamespaceModelsResponse\x12\x32\n\x06models\x18\x01 \x03(\x0b\x32\x1a.model.model.v1alpha.ModelR\x06models\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"x\n\x1b\x43reateNamespaceModelRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x30\n\x05model\x18\x02 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"P\n\x1c\x43reateNamespaceModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"\xa7\x01\n\x18GetNamespaceModelRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\x12\x38\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"M\n\x19GetNamespaceModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"\xe2\x01\n\x1bUpdateNamespaceModelRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\x12\x36\n\x05model\x18\x03 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x04\xe2\x41\x01\x02R\x05model\x12\x41\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"P\n\x1cUpdateNamespaceModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"g\n\x1b\x44\x65leteNamespaceModelRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\"\x1e\n\x1c\x44\x65leteNamespaceModelResponse\"\x8f\x01\n\x1bRenameNamespaceModelRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\x12&\n\x0cnew_model_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\nnewModelId\"P\n\x1cRenameNamespaceModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"\x86\x01\n\x1aWatchNamespaceModelRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\"o\n\x1bWatchNamespaceModelResponse\x12\x30\n\x05state\x18\x01 \x01(\x0e\x32\x1a.model.model.v1alpha.StateR\x05state\x12\x18\n\x07message\x18\x03 \x01(\tR\x07messageJ\x04\x08\x02\x10\x03\"l\n WatchNamespaceLatestModelRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\"u\n!WatchNamespaceLatestModelResponse\x12\x30\n\x05state\x18\x01 \x01(\x0e\x32\x1a.model.model.v1alpha.StateR\x05state\x12\x18\n\x07message\x18\x03 \x01(\tR\x07messageJ\x04\x08\x02\x10\x03\"\xcb\x01\n!ListNamespaceModelVersionsRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\x12&\n\tpage_size\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12\x1d\n\x04page\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x01R\x04page\x88\x01\x01\x42\x0c\n\n_page_sizeB\x07\n\x05_page\"\xcb\x01\n\"ListNamespaceModelVersionsResponse\x12\x43\n\x08versions\x18\x01 \x03(\x0b\x32!.model.model.v1alpha.ModelVersionB\x04\xe2\x41\x01\x03R\x08versions\x12#\n\ntotal_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x03R\ttotalSize\x12!\n\tpage_size\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x08pageSize\x12\x18\n\x04page\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x04page\"\x8e\x01\n\"DeleteNamespaceModelVersionRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\"%\n#DeleteNamespaceModelVersionResponse\"\xcf\x01\n\x1cTriggerNamespaceModelRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\x12\x45\n\x0btask_inputs\x18\x03 \x03(\x0b\x32\x1e.model.model.v1alpha.TaskInputB\x04\xe2\x41\x01\x02R\ntaskInputs\x12\x1e\n\x07version\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\"\x92\x01\n\x1dTriggerNamespaceModelResponse\x12-\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskR\x04task\x12\x42\n\x0ctask_outputs\x18\x02 \x03(\x0b\x32\x1f.model.model.v1alpha.TaskOutputR\x0btaskOutputs\"\xd4\x01\n!TriggerAsyncNamespaceModelRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\x12\x45\n\x0btask_inputs\x18\x03 \x03(\x0b\x32\x1e.model.model.v1alpha.TaskInputB\x04\xe2\x41\x01\x02R\ntaskInputs\x12\x1e\n\x07version\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\"g\n\"TriggerAsyncNamespaceModelResponse\x12\x41\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x04\xe2\x41\x01\x03R\toperation\"\xb5\x01\n\"TriggerNamespaceLatestModelRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\x12\x45\n\x0btask_inputs\x18\x03 \x03(\x0b\x32\x1e.model.model.v1alpha.TaskInputB\x04\xe2\x41\x01\x02R\ntaskInputs\"\x98\x01\n#TriggerNamespaceLatestModelResponse\x12-\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskR\x04task\x12\x42\n\x0ctask_outputs\x18\x02 \x03(\x0b\x32\x1f.model.model.v1alpha.TaskOutputR\x0btaskOutputs\"\xba\x01\n\'TriggerAsyncNamespaceLatestModelRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\x12\x45\n\x0btask_inputs\x18\x03 \x03(\x0b\x32\x1e.model.model.v1alpha.TaskInputB\x04\xe2\x41\x01\x02R\ntaskInputs\"m\n(TriggerAsyncNamespaceLatestModelResponse\x12\x41\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x04\xe2\x41\x01\x03R\toperation\"\xe3\x01\n,TriggerNamespaceModelBinaryFileUploadRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\x12I\n\ntask_input\x18\x03 \x01(\x0b\x32$.model.model.v1alpha.TaskInputStreamB\x04\xe2\x41\x01\x02R\ttaskInput\x12\x1e\n\x07version\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\"\xce\x01\n-TriggerNamespaceModelBinaryFileUploadResponse\x12\x33\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x04\xe2\x41\x01\x02R\x04task\x12H\n\x0ctask_outputs\x18\x02 \x03(\x0b\x32\x1f.model.model.v1alpha.TaskOutputB\x04\xe2\x41\x01\x02R\x0btaskOutputs\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\"\xc9\x01\n2TriggerNamespaceLatestModelBinaryFileUploadRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\x12I\n\ntask_input\x18\x03 \x01(\x0b\x32$.model.model.v1alpha.TaskInputStreamB\x04\xe2\x41\x01\x02R\ttaskInput\"\xb4\x01\n3TriggerNamespaceLatestModelBinaryFileUploadResponse\x12\x33\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x04\xe2\x41\x01\x02R\x04task\x12H\n\x0ctask_outputs\x18\x02 \x03(\x0b\x32\x1f.model.model.v1alpha.TaskOutputB\x04\xe2\x41\x01\x02R\x0btaskOutputs\"\xb6\x01\n\'GetNamespaceLatestModelOperationRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\x12\x38\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"g\n(GetNamespaceLatestModelOperationResponse\x12;\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationR\toperation\"\xaa\x01\n DeployNamespaceModelAdminRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\x12\x1c\n\x06\x64igest\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01R\x06\x64igest\")\n!DeployNamespaceModelAdminResponseJ\x04\x08\x01\x10\x02\"\xac\x01\n\"UndeployNamespaceModelAdminRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x1f\n\x08model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07modelId\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\x12\x1c\n\x06\x64igest\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01R\x06\x64igest\"+\n#UndeployNamespaceModelAdminResponseJ\x04\x08\x01\x10\x02\"\x95\x01\n\x16\x43reateUserModelRequest\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\x12I\n\x06parent\x18\x02 \x01(\tB1\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe2\x41\x01\x02\xfa\x41\x18\x12\x16\x61pi.instill.tech/ModelR\x06parent\"K\n\x17\x43reateUserModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"\x95\x04\n\x15ListUserModelsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x38\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12I\n\x06parent\x18\x04 \x01(\tB1\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe2\x41\x01\x02\xfa\x41\x18\x12\x16\x61pi.instill.tech/ModelR\x06parent\x12,\n\x0cshow_deleted\x18\x05 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x03R\x0bshowDeleted\x88\x01\x01\x12!\n\x06\x66ilter\x18\x06 \x01(\tB\x04\xe2\x41\x01\x01H\x04R\x06\x66ilter\x88\x01\x01\x12P\n\nvisibility\x18\x07 \x01(\x0e\x32%.model.model.v1alpha.Model.VisibilityB\x04\xe2\x41\x01\x01H\x05R\nvisibility\x88\x01\x01\x12$\n\x08order_by\x18\x08 \x01(\tB\x04\xe2\x41\x01\x01H\x06R\x07orderBy\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\x0f\n\r_show_deletedB\t\n\x07_filterB\r\n\x0b_visibilityB\x0b\n\t_order_by\"\x93\x01\n\x16ListUserModelsResponse\x12\x32\n\x06models\x18\x01 \x03(\x0b\x32\x1a.model.model.v1alpha.ModelR\x06models\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xa5\x01\n\x13GetUserModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x38\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"H\n\x14GetUserModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"\x93\x01\n\x16UpdateUserModelRequest\x12\x36\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x04\xe2\x41\x01\x02R\x05model\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"K\n\x17UpdateUserModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"e\n\x16\x44\x65leteUserModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"\x19\n\x17\x44\x65leteUserModelResponse\"\x8d\x01\n\x16RenameUserModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12&\n\x0cnew_model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\nnewModelId\"K\n\x17RenameUserModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"\x84\x01\n\x15WatchUserModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1e\n\x07version\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\"j\n\x16WatchUserModelResponse\x12\x30\n\x05state\x18\x01 \x01(\x0e\x32\x1a.model.model.v1alpha.StateR\x05state\x12\x18\n\x07message\x18\x03 \x01(\tR\x07messageJ\x04\x08\x02\x10\x03\"j\n\x1bWatchUserLatestModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"p\n\x1cWatchUserLatestModelResponse\x12\x30\n\x05state\x18\x01 \x01(\x0e\x32\x1a.model.model.v1alpha.StateR\x05state\x12\x18\n\x07message\x18\x03 \x01(\tR\x07messageJ\x04\x08\x02\x10\x03\"\xc9\x01\n\x1cListUserModelVersionsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12\x1d\n\x04page\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x01R\x04page\x88\x01\x01\x12K\n\x04name\x18\x03 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04nameB\x0c\n\n_page_sizeB\x07\n\x05_page\"\xae\x01\n\x1dListUserModelVersionsResponse\x12=\n\x08versions\x18\x01 \x03(\x0b\x32!.model.model.v1alpha.ModelVersionR\x08versions\x12\x1d\n\ntotal_size\x18\x02 \x01(\x05R\ttotalSize\x12\x1b\n\tpage_size\x18\x03 \x01(\x05R\x08pageSize\x12\x12\n\x04page\x18\x04 \x01(\x05R\x04page\"\x8c\x01\n\x1d\x44\x65leteUserModelVersionRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1e\n\x07version\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\" \n\x1e\x44\x65leteUserModelVersionResponse\"\x80\x08\n\tTaskInput\x12R\n\x0e\x63lassification\x18\x01 \x01(\x0b\x32(.model.model.v1alpha.ClassificationInputH\x00R\x0e\x63lassification\x12\x43\n\tdetection\x18\x02 \x01(\x0b\x32#.model.model.v1alpha.DetectionInputH\x00R\tdetection\x12@\n\x08keypoint\x18\x03 \x01(\x0b\x32\".model.model.v1alpha.KeypointInputH\x00R\x08keypoint\x12\x31\n\x03ocr\x18\x04 \x01(\x0b\x32\x1d.model.model.v1alpha.OcrInputH\x00R\x03ocr\x12\x65\n\x15instance_segmentation\x18\x05 \x01(\x0b\x32..model.model.v1alpha.InstanceSegmentationInputH\x00R\x14instanceSegmentation\x12\x65\n\x15semantic_segmentation\x18\x06 \x01(\x0b\x32..model.model.v1alpha.SemanticSegmentationInputH\x00R\x14semanticSegmentation\x12K\n\rtext_to_image\x18\x07 \x01(\x0b\x32%.model.model.v1alpha.TextToImageInputH\x00R\x0btextToImage\x12N\n\x0eimage_to_image\x18\x08 \x01(\x0b\x32&.model.model.v1alpha.ImageToImageInputH\x00R\x0cimageToImage\x12S\n\x0ftext_generation\x18\t \x01(\x0b\x32(.model.model.v1alpha.TextGenerationInputH\x00R\x0etextGeneration\x12`\n\x14text_generation_chat\x18\n \x01(\x0b\x32,.model.model.v1alpha.TextGenerationChatInputH\x00R\x12textGenerationChat\x12o\n\x19visual_question_answering\x18\x0b \x01(\x0b\x32\x31.model.model.v1alpha.VisualQuestionAnsweringInputH\x00R\x17visualQuestionAnswering\x12I\n\x0bunspecified\x18\x0c \x01(\x0b\x32%.model.model.v1alpha.UnspecifiedInputH\x00R\x0bunspecifiedB\x07\n\x05input\"\xaa\x08\n\x0fTaskInputStream\x12X\n\x0e\x63lassification\x18\x01 \x01(\x0b\x32..model.model.v1alpha.ClassificationInputStreamH\x00R\x0e\x63lassification\x12I\n\tdetection\x18\x02 \x01(\x0b\x32).model.model.v1alpha.DetectionInputStreamH\x00R\tdetection\x12\x46\n\x08keypoint\x18\x03 \x01(\x0b\x32(.model.model.v1alpha.KeypointInputStreamH\x00R\x08keypoint\x12\x37\n\x03ocr\x18\x04 \x01(\x0b\x32#.model.model.v1alpha.OcrInputStreamH\x00R\x03ocr\x12k\n\x15instance_segmentation\x18\x05 \x01(\x0b\x32\x34.model.model.v1alpha.InstanceSegmentationInputStreamH\x00R\x14instanceSegmentation\x12k\n\x15semantic_segmentation\x18\x06 \x01(\x0b\x32\x34.model.model.v1alpha.SemanticSegmentationInputStreamH\x00R\x14semanticSegmentation\x12K\n\rtext_to_image\x18\x07 \x01(\x0b\x32%.model.model.v1alpha.TextToImageInputH\x00R\x0btextToImage\x12N\n\x0eimage_to_image\x18\x08 \x01(\x0b\x32&.model.model.v1alpha.ImageToImageInputH\x00R\x0cimageToImage\x12S\n\x0ftext_generation\x18\t \x01(\x0b\x32(.model.model.v1alpha.TextGenerationInputH\x00R\x0etextGeneration\x12`\n\x14text_generation_chat\x18\n \x01(\x0b\x32,.model.model.v1alpha.TextGenerationChatInputH\x00R\x12textGenerationChat\x12o\n\x19visual_question_answering\x18\x0b \x01(\x0b\x32\x31.model.model.v1alpha.VisualQuestionAnsweringInputH\x00R\x17visualQuestionAnswering\x12I\n\x0bunspecified\x18\x0c \x01(\x0b\x32%.model.model.v1alpha.UnspecifiedInputH\x00R\x0bunspecifiedB\x07\n\x05input\"\xd6\x08\n\nTaskOutput\x12Y\n\x0e\x63lassification\x18\x01 \x01(\x0b\x32).model.model.v1alpha.ClassificationOutputB\x04\xe2\x41\x01\x03H\x00R\x0e\x63lassification\x12J\n\tdetection\x18\x02 \x01(\x0b\x32$.model.model.v1alpha.DetectionOutputB\x04\xe2\x41\x01\x03H\x00R\tdetection\x12G\n\x08keypoint\x18\x03 \x01(\x0b\x32#.model.model.v1alpha.KeypointOutputB\x04\xe2\x41\x01\x03H\x00R\x08keypoint\x12\x38\n\x03ocr\x18\x04 \x01(\x0b\x32\x1e.model.model.v1alpha.OcrOutputB\x04\xe2\x41\x01\x03H\x00R\x03ocr\x12l\n\x15instance_segmentation\x18\x05 \x01(\x0b\x32/.model.model.v1alpha.InstanceSegmentationOutputB\x04\xe2\x41\x01\x03H\x00R\x14instanceSegmentation\x12l\n\x15semantic_segmentation\x18\x06 \x01(\x0b\x32/.model.model.v1alpha.SemanticSegmentationOutputB\x04\xe2\x41\x01\x03H\x00R\x14semanticSegmentation\x12R\n\rtext_to_image\x18\x07 \x01(\x0b\x32&.model.model.v1alpha.TextToImageOutputB\x04\xe2\x41\x01\x03H\x00R\x0btextToImage\x12U\n\x0eimage_to_image\x18\x08 \x01(\x0b\x32\'.model.model.v1alpha.ImageToImageOutputB\x04\xe2\x41\x01\x03H\x00R\x0cimageToImage\x12Z\n\x0ftext_generation\x18\t \x01(\x0b\x32).model.model.v1alpha.TextGenerationOutputB\x04\xe2\x41\x01\x03H\x00R\x0etextGeneration\x12g\n\x14text_generation_chat\x18\n \x01(\x0b\x32-.model.model.v1alpha.TextGenerationChatOutputB\x04\xe2\x41\x01\x03H\x00R\x12textGenerationChat\x12v\n\x19visual_question_answering\x18\x0b \x01(\x0b\x32\x32.model.model.v1alpha.VisualQuestionAnsweringOutputB\x04\xe2\x41\x01\x03H\x00R\x17visualQuestionAnswering\x12P\n\x0bunspecified\x18\x0c \x01(\x0b\x32&.model.model.v1alpha.UnspecifiedOutputB\x04\xe2\x41\x01\x03H\x00R\x0bunspecifiedB\x08\n\x06output\"\xcd\x01\n\x17TriggerUserModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x45\n\x0btask_inputs\x18\x02 \x03(\x0b\x32\x1e.model.model.v1alpha.TaskInputB\x04\xe2\x41\x01\x02R\ntaskInputs\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\"\x8d\x01\n\x18TriggerUserModelResponse\x12-\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskR\x04task\x12\x42\n\x0ctask_outputs\x18\x02 \x03(\x0b\x32\x1f.model.model.v1alpha.TaskOutputR\x0btaskOutputs\"\xd2\x01\n\x1cTriggerAsyncUserModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x45\n\x0btask_inputs\x18\x02 \x03(\x0b\x32\x1e.model.model.v1alpha.TaskInputB\x04\xe2\x41\x01\x02R\ntaskInputs\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\"b\n\x1dTriggerAsyncUserModelResponse\x12\x41\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x04\xe2\x41\x01\x03R\toperation\"\xb3\x01\n\x1dTriggerUserLatestModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x45\n\x0btask_inputs\x18\x02 \x03(\x0b\x32\x1e.model.model.v1alpha.TaskInputB\x04\xe2\x41\x01\x02R\ntaskInputs\"\x93\x01\n\x1eTriggerUserLatestModelResponse\x12-\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskR\x04task\x12\x42\n\x0ctask_outputs\x18\x02 \x03(\x0b\x32\x1f.model.model.v1alpha.TaskOutputR\x0btaskOutputs\"\xb8\x01\n\"TriggerAsyncUserLatestModelRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x45\n\x0btask_inputs\x18\x02 \x03(\x0b\x32\x1e.model.model.v1alpha.TaskInputB\x04\xe2\x41\x01\x02R\ntaskInputs\"h\n#TriggerAsyncUserLatestModelResponse\x12\x41\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x04\xe2\x41\x01\x03R\toperation\"\xe1\x01\n\'TriggerUserModelBinaryFileUploadRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12I\n\ntask_input\x18\x02 \x01(\x0b\x32$.model.model.v1alpha.TaskInputStreamB\x04\xe2\x41\x01\x02R\ttaskInput\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\"\xc9\x01\n(TriggerUserModelBinaryFileUploadResponse\x12\x33\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x04\xe2\x41\x01\x02R\x04task\x12H\n\x0ctask_outputs\x18\x02 \x03(\x0b\x32\x1f.model.model.v1alpha.TaskOutputB\x04\xe2\x41\x01\x02R\x0btaskOutputs\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\"\xa5\x01\n\x1e\x43reateOrganizationModelRequest\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\x12Q\n\x06parent\x18\x02 \x01(\tB9\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe2\x41\x01\x02\xfa\x41\x18\x12\x16\x61pi.instill.tech/ModelR\x06parent\"S\n\x1f\x43reateOrganizationModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"\xa5\x04\n\x1dListOrganizationModelsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x38\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12Q\n\x06parent\x18\x04 \x01(\tB9\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe2\x41\x01\x02\xfa\x41\x18\x12\x16\x61pi.instill.tech/ModelR\x06parent\x12,\n\x0cshow_deleted\x18\x05 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x03R\x0bshowDeleted\x88\x01\x01\x12!\n\x06\x66ilter\x18\x06 \x01(\tB\x04\xe2\x41\x01\x01H\x04R\x06\x66ilter\x88\x01\x01\x12P\n\nvisibility\x18\x07 \x01(\x0e\x32%.model.model.v1alpha.Model.VisibilityB\x04\xe2\x41\x01\x01H\x05R\nvisibility\x88\x01\x01\x12$\n\x08order_by\x18\x08 \x01(\tB\x04\xe2\x41\x01\x01H\x06R\x07orderBy\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\x0f\n\r_show_deletedB\t\n\x07_filterB\r\n\x0b_visibilityB\x0b\n\t_order_by\"\x9b\x01\n\x1eListOrganizationModelsResponse\x12\x32\n\x06models\x18\x01 \x03(\x0b\x32\x1a.model.model.v1alpha.ModelR\x06models\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xb5\x01\n\x1bGetOrganizationModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x38\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"P\n\x1cGetOrganizationModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"\x9b\x01\n\x1eUpdateOrganizationModelRequest\x12\x36\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelB\x04\xe2\x41\x01\x02R\x05model\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"S\n\x1fUpdateOrganizationModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"u\n\x1e\x44\x65leteOrganizationModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"!\n\x1f\x44\x65leteOrganizationModelResponse\"\x9d\x01\n\x1eRenameOrganizationModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12&\n\x0cnew_model_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\nnewModelId\"S\n\x1fRenameOrganizationModelResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"\x94\x01\n\x1dWatchOrganizationModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1e\n\x07version\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\"r\n\x1eWatchOrganizationModelResponse\x12\x30\n\x05state\x18\x01 \x01(\x0e\x32\x1a.model.model.v1alpha.StateR\x05state\x12\x18\n\x07message\x18\x03 \x01(\tR\x07messageJ\x04\x08\x02\x10\x03\"z\n#WatchOrganizationLatestModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\"x\n$WatchOrganizationLatestModelResponse\x12\x30\n\x05state\x18\x01 \x01(\x0e\x32\x1a.model.model.v1alpha.StateR\x05state\x12\x18\n\x07message\x18\x03 \x01(\tR\x07messageJ\x04\x08\x02\x10\x03\"\xd9\x01\n$ListOrganizationModelVersionsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12\x1d\n\x04page\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x01R\x04page\x88\x01\x01\x12S\n\x04name\x18\x03 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04nameB\x0c\n\n_page_sizeB\x07\n\x05_page\"\xb6\x01\n%ListOrganizationModelVersionsResponse\x12=\n\x08versions\x18\x01 \x03(\x0b\x32!.model.model.v1alpha.ModelVersionR\x08versions\x12\x1d\n\ntotal_size\x18\x02 \x01(\x05R\ttotalSize\x12\x1b\n\tpage_size\x18\x03 \x01(\x05R\x08pageSize\x12\x12\n\x04page\x18\x04 \x01(\x05R\x04page\"\x9c\x01\n%DeleteOrganizationModelVersionRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1e\n\x07version\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\"(\n&DeleteOrganizationModelVersionResponse\"\xdd\x01\n\x1fTriggerOrganizationModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x45\n\x0btask_inputs\x18\x02 \x03(\x0b\x32\x1e.model.model.v1alpha.TaskInputB\x04\xe2\x41\x01\x02R\ntaskInputs\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\"\x95\x01\n TriggerOrganizationModelResponse\x12-\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskR\x04task\x12\x42\n\x0ctask_outputs\x18\x02 \x03(\x0b\x32\x1f.model.model.v1alpha.TaskOutputR\x0btaskOutputs\"\xe2\x01\n$TriggerAsyncOrganizationModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x45\n\x0btask_inputs\x18\x02 \x03(\x0b\x32\x1e.model.model.v1alpha.TaskInputB\x04\xe2\x41\x01\x02R\ntaskInputs\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\"j\n%TriggerAsyncOrganizationModelResponse\x12\x41\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x04\xe2\x41\x01\x03R\toperation\"\xc3\x01\n%TriggerOrganizationLatestModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x45\n\x0btask_inputs\x18\x02 \x03(\x0b\x32\x1e.model.model.v1alpha.TaskInputB\x04\xe2\x41\x01\x02R\ntaskInputs\"\x9b\x01\n&TriggerOrganizationLatestModelResponse\x12-\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskR\x04task\x12\x42\n\x0ctask_outputs\x18\x02 \x03(\x0b\x32\x1f.model.model.v1alpha.TaskOutputR\x0btaskOutputs\"\xc8\x01\n*TriggerAsyncOrganizationLatestModelRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x45\n\x0btask_inputs\x18\x02 \x03(\x0b\x32\x1e.model.model.v1alpha.TaskInputB\x04\xe2\x41\x01\x02R\ntaskInputs\"p\n+TriggerAsyncOrganizationLatestModelResponse\x12\x41\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationB\x04\xe2\x41\x01\x03R\toperation\"\xf1\x01\n/TriggerOrganizationModelBinaryFileUploadRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12I\n\ntask_input\x18\x02 \x01(\x0b\x32$.model.model.v1alpha.TaskInputStreamB\x04\xe2\x41\x01\x02R\ttaskInput\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\"\xb1\x01\n0TriggerOrganizationModelBinaryFileUploadResponse\x12\x33\n\x04task\x18\x01 \x01(\x0e\x32\x19.common.task.v1alpha.TaskB\x04\xe2\x41\x01\x02R\x04task\x12H\n\x0ctask_outputs\x18\x02 \x03(\x0b\x32\x1f.model.model.v1alpha.TaskOutputB\x04\xe2\x41\x01\x02R\x0btaskOutputs\"\x88\x01\n\x18GetModelOperationRequest\x12\'\n\x0coperation_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0boperationId\x12:\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x06\x18\x01\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"X\n\x19GetModelOperationResponse\x12;\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationR\toperation\"\xba\x01\n\x0fLatestOperation\x12K\n\x07request\x18\x03 \x01(\x0b\x32\x31.model.model.v1alpha.TriggerNamespaceModelRequestR\x07request\x12N\n\x08response\x18\x04 \x01(\x0b\x32\x32.model.model.v1alpha.TriggerNamespaceModelResponseR\x08responseJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\xb4\x01\n\"GetUserLatestModelOperationRequest\x12K\n\x04name\x18\x01 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x38\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"b\n#GetUserLatestModelOperationResponse\x12;\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationR\toperation\"\xc4\x01\n*GetOrganizationLatestModelOperationRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x38\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"j\n+GetOrganizationLatestModelOperationResponse\x12;\n\toperation\x18\x01 \x01(\x0b\x32\x1d.google.longrunning.OperationR\toperation\"\x1d\n\x1bListAvailableRegionsRequest\"U\n\x1cListAvailableRegionsResponse\x12\x35\n\x07regions\x18\x01 \x03(\x0b\x32\x1b.model.model.v1alpha.RegionR\x07regions\"\xb7\x02\n\x16ListModelsAdminRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x38\n\x04view\x18\x03 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12,\n\x0cshow_deleted\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x03R\x0bshowDeleted\x88\x01\x01\x12!\n\x06\x66ilter\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01H\x04R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\x0f\n\r_show_deletedB\t\n\x07_filter\"\x94\x01\n\x17ListModelsAdminResponse\x12\x32\n\x06models\x18\x01 \x03(\x0b\x32\x1a.model.model.v1alpha.ModelR\x06models\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\x80\x01\n\x17LookUpModelAdminRequest\x12\"\n\tpermalink\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\tpermalink\x12\x38\n\x04view\x18\x02 \x01(\x0e\x32\x19.model.model.v1alpha.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"L\n\x18LookUpModelAdminResponse\x12\x30\n\x05model\x18\x01 \x01(\x0b\x32\x1a.model.model.v1alpha.ModelR\x05model\"\xae\x01\n\x1b\x44\x65ployUserModelAdminRequest\x12K\n\x04name\x18\x02 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\x12\x1c\n\x06\x64igest\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01R\x06\x64igestJ\x04\x08\x01\x10\x02\"$\n\x1c\x44\x65ployUserModelAdminResponseJ\x04\x08\x01\x10\x02\"\xbe\x01\n#DeployOrganizationModelAdminRequest\x12S\n\x04name\x18\x02 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\x12\x1c\n\x06\x64igest\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01R\x06\x64igestJ\x04\x08\x01\x10\x02\"&\n$DeployOrganizationModelAdminResponse\"\xb0\x01\n\x1dUndeployUserModelAdminRequest\x12K\n\x04name\x18\x02 \x01(\tB7\x92\x41\x15\xca>\x12\xfa\x02\x0fuser_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\x12\x1c\n\x06\x64igest\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01R\x06\x64igestJ\x04\x08\x01\x10\x02\"&\n\x1eUndeployUserModelAdminResponseJ\x04\x08\x01\x10\x02\"\xc0\x01\n%UndeployOrganizationModelAdminRequest\x12S\n\x04name\x18\x02 \x01(\tB?\x92\x41\x1d\xca>\x1a\xfa\x02\x17organization_model_name\xe2\x41\x01\x02\xfa\x41\x18\n\x16\x61pi.instill.tech/ModelR\x04name\x12\x1e\n\x07version\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x07version\x12\x1c\n\x06\x64igest\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01R\x06\x64igestJ\x04\x08\x01\x10\x02\"(\n&UndeployOrganizationModelAdminResponse*\x8b\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x11\n\rSTATE_OFFLINE\x10\x01\x12\x11\n\rSTATE_SCALING\x10\x02\x12\x10\n\x0cSTATE_ACTIVE\x10\x03\x12\x0e\n\nSTATE_IDLE\x10\x04\x12\x0f\n\x0bSTATE_ERROR\x10\x05\x12\x12\n\x0eSTATE_STARTING\x10\x06\x42\xd7\x01\n\x17\x63om.model.model.v1alphaB\nModelProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.model_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\nModelProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _LIVENESSREQUEST.fields_by_name['health_check_request']._options = None
  _LIVENESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\342A\001\001'
  _READINESSREQUEST.fields_by_name['health_check_request']._options = None
  _READINESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\342A\001\001'
  _MODELVERSION.fields_by_name['name']._options = None
  _MODELVERSION.fields_by_name['name']._serialized_options = b'\342A\001\005'
  _MODELVERSION.fields_by_name['version']._options = None
  _MODELVERSION.fields_by_name['version']._serialized_options = b'\342A\001\005'
  _MODELVERSION.fields_by_name['digest']._options = None
  _MODELVERSION.fields_by_name['digest']._serialized_options = b'\342A\001\001'
  _MODELVERSION.fields_by_name['state']._options = None
  _MODELVERSION.fields_by_name['state']._serialized_options = b'\342A\001\003'
  _MODELVERSION.fields_by_name['update_time']._options = None
  _MODELVERSION.fields_by_name['update_time']._serialized_options = b'\342A\002\003\001'
  _MODEL.fields_by_name['name']._options = None
  _MODEL.fields_by_name['name']._serialized_options = b'\222A\020\312>\r\372\002\nmodel_name\342A\001\003'
  _MODEL.fields_by_name['uid']._options = None
  _MODEL.fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['id']._options = None
  _MODEL.fields_by_name['id']._serialized_options = b'\342A\002\002\005'
  _MODEL.fields_by_name['description']._options = None
  _MODEL.fields_by_name['description']._serialized_options = b'\342A\001\001'
  _MODEL.fields_by_name['model_definition']._options = None
  _MODEL.fields_by_name['model_definition']._serialized_options = b'\342A\002\002\005\372A\"\n api.instill.tech/ModelDefinition'
  _MODEL.fields_by_name['configuration']._options = None
  _MODEL.fields_by_name['configuration']._serialized_options = b'\342A\002\002\005'
  _MODEL.fields_by_name['task']._options = None
  _MODEL.fields_by_name['task']._serialized_options = b'\342A\002\002\005'
  _MODEL.fields_by_name['visibility']._options = None
  _MODEL.fields_by_name['visibility']._serialized_options = b'\342A\001\002'
  _MODEL.fields_by_name['create_time']._options = None
  _MODEL.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['update_time']._options = None
  _MODEL.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['delete_time']._options = None
  _MODEL.fields_by_name['delete_time']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['owner_name']._options = None
  _MODEL.fields_by_name['owner_name']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['owner']._options = None
  _MODEL.fields_by_name['owner']._serialized_options = b'\342A\002\001\003'
  _MODEL.fields_by_name['region']._options = None
  _MODEL.fields_by_name['region']._serialized_options = b'\342A\002\002\005'
  _MODEL.fields_by_name['hardware']._options = None
  _MODEL.fields_by_name['hardware']._serialized_options = b'\342A\001\002'
  _MODEL.fields_by_name['readme']._options = None
  _MODEL.fields_by_name['readme']._serialized_options = b'\342A\001\001'
  _MODEL.fields_by_name['source_url']._options = None
  _MODEL.fields_by_name['source_url']._serialized_options = b'\342A\001\001'
  _MODEL.fields_by_name['documentation_url']._options = None
  _MODEL.fields_by_name['documentation_url']._serialized_options = b'\342A\001\001'
  _MODEL.fields_by_name['license']._options = None
  _MODEL.fields_by_name['license']._serialized_options = b'\342A\001\001'
  _MODEL.fields_by_name['sample_input']._options = None
  _MODEL.fields_by_name['sample_input']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['sample_output']._options = None
  _MODEL.fields_by_name['sample_output']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['profile_image']._options = None
  _MODEL.fields_by_name['profile_image']._serialized_options = b'\342A\001\001'
  _MODEL.fields_by_name['permission']._options = None
  _MODEL.fields_by_name['permission']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['input_schema']._options = None
  _MODEL.fields_by_name['input_schema']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['output_schema']._options = None
  _MODEL.fields_by_name['output_schema']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['tags']._options = None
  _MODEL.fields_by_name['tags']._serialized_options = b'\342A\001\003'
  _MODEL.fields_by_name['versions']._options = None
  _MODEL.fields_by_name['versions']._serialized_options = b'\342A\001\003'
  _MODEL._options = None
  _MODEL._serialized_options = b'\352AO\n\026api.instill.tech/Model\022!users/{user.id}/models/{model.id}\022\022models/{model.uid}'
  _LISTMODELSREQUEST.fields_by_name['page_size']._options = None
  _LISTMODELSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTMODELSREQUEST.fields_by_name['page_token']._options = None
  _LISTMODELSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTMODELSREQUEST.fields_by_name['view']._options = None
  _LISTMODELSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTMODELSREQUEST.fields_by_name['show_deleted']._options = None
  _LISTMODELSREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _LISTMODELSREQUEST.fields_by_name['filter']._options = None
  _LISTMODELSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTMODELSREQUEST.fields_by_name['visibility']._options = None
  _LISTMODELSREQUEST.fields_by_name['visibility']._serialized_options = b'\342A\001\001'
  _LISTMODELSREQUEST.fields_by_name['order_by']._options = None
  _LISTMODELSREQUEST.fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _LOOKUPMODELREQUEST.fields_by_name['permalink']._options = None
  _LOOKUPMODELREQUEST.fields_by_name['permalink']._serialized_options = b'\342A\001\002'
  _LOOKUPMODELREQUEST.fields_by_name['view']._options = None
  _LOOKUPMODELREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['page_size']._options = None
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['page_token']._options = None
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['view']._options = None
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['show_deleted']._options = None
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['filter']._options = None
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['visibility']._options = None
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['visibility']._serialized_options = b'\342A\001\001'
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['order_by']._options = None
  _LISTNAMESPACEMODELSREQUEST.fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _CREATENAMESPACEMODELREQUEST.fields_by_name['namespace_id']._options = None
  _CREATENAMESPACEMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _GETNAMESPACEMODELREQUEST.fields_by_name['namespace_id']._options = None
  _GETNAMESPACEMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _GETNAMESPACEMODELREQUEST.fields_by_name['model_id']._options = None
  _GETNAMESPACEMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _GETNAMESPACEMODELREQUEST.fields_by_name['view']._options = None
  _GETNAMESPACEMODELREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _UPDATENAMESPACEMODELREQUEST.fields_by_name['namespace_id']._options = None
  _UPDATENAMESPACEMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _UPDATENAMESPACEMODELREQUEST.fields_by_name['model_id']._options = None
  _UPDATENAMESPACEMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _UPDATENAMESPACEMODELREQUEST.fields_by_name['model']._options = None
  _UPDATENAMESPACEMODELREQUEST.fields_by_name['model']._serialized_options = b'\342A\001\002'
  _UPDATENAMESPACEMODELREQUEST.fields_by_name['update_mask']._options = None
  _UPDATENAMESPACEMODELREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _DELETENAMESPACEMODELREQUEST.fields_by_name['namespace_id']._options = None
  _DELETENAMESPACEMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _DELETENAMESPACEMODELREQUEST.fields_by_name['model_id']._options = None
  _DELETENAMESPACEMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _RENAMENAMESPACEMODELREQUEST.fields_by_name['namespace_id']._options = None
  _RENAMENAMESPACEMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _RENAMENAMESPACEMODELREQUEST.fields_by_name['model_id']._options = None
  _RENAMENAMESPACEMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _RENAMENAMESPACEMODELREQUEST.fields_by_name['new_model_id']._options = None
  _RENAMENAMESPACEMODELREQUEST.fields_by_name['new_model_id']._serialized_options = b'\342A\001\002'
  _WATCHNAMESPACEMODELREQUEST.fields_by_name['namespace_id']._options = None
  _WATCHNAMESPACEMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _WATCHNAMESPACEMODELREQUEST.fields_by_name['model_id']._options = None
  _WATCHNAMESPACEMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _WATCHNAMESPACEMODELREQUEST.fields_by_name['version']._options = None
  _WATCHNAMESPACEMODELREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _WATCHNAMESPACELATESTMODELREQUEST.fields_by_name['namespace_id']._options = None
  _WATCHNAMESPACELATESTMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _WATCHNAMESPACELATESTMODELREQUEST.fields_by_name['model_id']._options = None
  _WATCHNAMESPACELATESTMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _LISTNAMESPACEMODELVERSIONSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTNAMESPACEMODELVERSIONSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _LISTNAMESPACEMODELVERSIONSREQUEST.fields_by_name['model_id']._options = None
  _LISTNAMESPACEMODELVERSIONSREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _LISTNAMESPACEMODELVERSIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTNAMESPACEMODELVERSIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTNAMESPACEMODELVERSIONSREQUEST.fields_by_name['page']._options = None
  _LISTNAMESPACEMODELVERSIONSREQUEST.fields_by_name['page']._serialized_options = b'\342A\001\001'
  _LISTNAMESPACEMODELVERSIONSRESPONSE.fields_by_name['versions']._options = None
  _LISTNAMESPACEMODELVERSIONSRESPONSE.fields_by_name['versions']._serialized_options = b'\342A\001\003'
  _LISTNAMESPACEMODELVERSIONSRESPONSE.fields_by_name['total_size']._options = None
  _LISTNAMESPACEMODELVERSIONSRESPONSE.fields_by_name['total_size']._serialized_options = b'\342A\001\003'
  _LISTNAMESPACEMODELVERSIONSRESPONSE.fields_by_name['page_size']._options = None
  _LISTNAMESPACEMODELVERSIONSRESPONSE.fields_by_name['page_size']._serialized_options = b'\342A\001\003'
  _LISTNAMESPACEMODELVERSIONSRESPONSE.fields_by_name['page']._options = None
  _LISTNAMESPACEMODELVERSIONSRESPONSE.fields_by_name['page']._serialized_options = b'\342A\001\003'
  _DELETENAMESPACEMODELVERSIONREQUEST.fields_by_name['namespace_id']._options = None
  _DELETENAMESPACEMODELVERSIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _DELETENAMESPACEMODELVERSIONREQUEST.fields_by_name['model_id']._options = None
  _DELETENAMESPACEMODELVERSIONREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _DELETENAMESPACEMODELVERSIONREQUEST.fields_by_name['version']._options = None
  _DELETENAMESPACEMODELVERSIONREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACEMODELREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERNAMESPACEMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACEMODELREQUEST.fields_by_name['model_id']._options = None
  _TRIGGERNAMESPACEMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACEMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERNAMESPACEMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACEMODELREQUEST.fields_by_name['version']._options = None
  _TRIGGERNAMESPACEMODELREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCNAMESPACEMODELREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERASYNCNAMESPACEMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCNAMESPACEMODELREQUEST.fields_by_name['model_id']._options = None
  _TRIGGERASYNCNAMESPACEMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCNAMESPACEMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERASYNCNAMESPACEMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCNAMESPACEMODELREQUEST.fields_by_name['version']._options = None
  _TRIGGERASYNCNAMESPACEMODELREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCNAMESPACEMODELRESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCNAMESPACEMODELRESPONSE.fields_by_name['operation']._serialized_options = b'\342A\001\003'
  _TRIGGERNAMESPACELATESTMODELREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERNAMESPACELATESTMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACELATESTMODELREQUEST.fields_by_name['model_id']._options = None
  _TRIGGERNAMESPACELATESTMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACELATESTMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERNAMESPACELATESTMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCNAMESPACELATESTMODELREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERASYNCNAMESPACELATESTMODELREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCNAMESPACELATESTMODELREQUEST.fields_by_name['model_id']._options = None
  _TRIGGERASYNCNAMESPACELATESTMODELREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCNAMESPACELATESTMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERASYNCNAMESPACELATESTMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCNAMESPACELATESTMODELRESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCNAMESPACELATESTMODELRESPONSE.fields_by_name['operation']._serialized_options = b'\342A\001\003'
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST.fields_by_name['model_id']._options = None
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_input']._options = None
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_input']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST.fields_by_name['version']._options = None
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._options = None
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._options = None
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADRESPONSE.fields_by_name['version']._options = None
  _TRIGGERNAMESPACEMODELBINARYFILEUPLOADRESPONSE.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADREQUEST.fields_by_name['namespace_id']._options = None
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADREQUEST.fields_by_name['model_id']._options = None
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_input']._options = None
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_input']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._options = None
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._serialized_options = b'\342A\001\002'
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._options = None
  _TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._serialized_options = b'\342A\001\002'
  _GETNAMESPACELATESTMODELOPERATIONREQUEST.fields_by_name['namespace_id']._options = None
  _GETNAMESPACELATESTMODELOPERATIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _GETNAMESPACELATESTMODELOPERATIONREQUEST.fields_by_name['model_id']._options = None
  _GETNAMESPACELATESTMODELOPERATIONREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _GETNAMESPACELATESTMODELOPERATIONREQUEST.fields_by_name['view']._options = None
  _GETNAMESPACELATESTMODELOPERATIONREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _DEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['namespace_id']._options = None
  _DEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _DEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['model_id']._options = None
  _DEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _DEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['version']._options = None
  _DEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _DEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['digest']._options = None
  _DEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['digest']._serialized_options = b'\342A\001\001'
  _UNDEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['namespace_id']._options = None
  _UNDEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _UNDEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['model_id']._options = None
  _UNDEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['model_id']._serialized_options = b'\342A\001\002'
  _UNDEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['version']._options = None
  _UNDEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _UNDEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['digest']._options = None
  _UNDEPLOYNAMESPACEMODELADMINREQUEST.fields_by_name['digest']._serialized_options = b'\342A\001\001'
  _CREATEUSERMODELREQUEST.fields_by_name['parent']._options = None
  _CREATEUSERMODELREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\342A\001\002\372A\030\022\026api.instill.tech/Model'
  _LISTUSERMODELSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTUSERMODELSREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTUSERMODELSREQUEST.fields_by_name['view']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTUSERMODELSREQUEST.fields_by_name['parent']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\342A\001\002\372A\030\022\026api.instill.tech/Model'
  _LISTUSERMODELSREQUEST.fields_by_name['show_deleted']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _LISTUSERMODELSREQUEST.fields_by_name['filter']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTUSERMODELSREQUEST.fields_by_name['visibility']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['visibility']._serialized_options = b'\342A\001\001'
  _LISTUSERMODELSREQUEST.fields_by_name['order_by']._options = None
  _LISTUSERMODELSREQUEST.fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _GETUSERMODELREQUEST.fields_by_name['name']._options = None
  _GETUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _GETUSERMODELREQUEST.fields_by_name['view']._options = None
  _GETUSERMODELREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _UPDATEUSERMODELREQUEST.fields_by_name['model']._options = None
  _UPDATEUSERMODELREQUEST.fields_by_name['model']._serialized_options = b'\342A\001\002'
  _UPDATEUSERMODELREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEUSERMODELREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _DELETEUSERMODELREQUEST.fields_by_name['name']._options = None
  _DELETEUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _RENAMEUSERMODELREQUEST.fields_by_name['name']._options = None
  _RENAMEUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _RENAMEUSERMODELREQUEST.fields_by_name['new_model_id']._options = None
  _RENAMEUSERMODELREQUEST.fields_by_name['new_model_id']._serialized_options = b'\342A\001\002'
  _WATCHUSERMODELREQUEST.fields_by_name['name']._options = None
  _WATCHUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _WATCHUSERMODELREQUEST.fields_by_name['version']._options = None
  _WATCHUSERMODELREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _WATCHUSERLATESTMODELREQUEST.fields_by_name['name']._options = None
  _WATCHUSERLATESTMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _LISTUSERMODELVERSIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERMODELVERSIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTUSERMODELVERSIONSREQUEST.fields_by_name['page']._options = None
  _LISTUSERMODELVERSIONSREQUEST.fields_by_name['page']._serialized_options = b'\342A\001\001'
  _LISTUSERMODELVERSIONSREQUEST.fields_by_name['name']._options = None
  _LISTUSERMODELVERSIONSREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _DELETEUSERMODELVERSIONREQUEST.fields_by_name['name']._options = None
  _DELETEUSERMODELVERSIONREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _DELETEUSERMODELVERSIONREQUEST.fields_by_name['version']._options = None
  _DELETEUSERMODELVERSIONREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _TASKOUTPUT.fields_by_name['classification']._options = None
  _TASKOUTPUT.fields_by_name['classification']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['detection']._options = None
  _TASKOUTPUT.fields_by_name['detection']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['keypoint']._options = None
  _TASKOUTPUT.fields_by_name['keypoint']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['ocr']._options = None
  _TASKOUTPUT.fields_by_name['ocr']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['instance_segmentation']._options = None
  _TASKOUTPUT.fields_by_name['instance_segmentation']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['semantic_segmentation']._options = None
  _TASKOUTPUT.fields_by_name['semantic_segmentation']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['text_to_image']._options = None
  _TASKOUTPUT.fields_by_name['text_to_image']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['image_to_image']._options = None
  _TASKOUTPUT.fields_by_name['image_to_image']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['text_generation']._options = None
  _TASKOUTPUT.fields_by_name['text_generation']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['text_generation_chat']._options = None
  _TASKOUTPUT.fields_by_name['text_generation_chat']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['visual_question_answering']._options = None
  _TASKOUTPUT.fields_by_name['visual_question_answering']._serialized_options = b'\342A\001\003'
  _TASKOUTPUT.fields_by_name['unspecified']._options = None
  _TASKOUTPUT.fields_by_name['unspecified']._serialized_options = b'\342A\001\003'
  _TRIGGERUSERMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERUSERMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERUSERMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERUSERMODELREQUEST.fields_by_name['version']._options = None
  _TRIGGERUSERMODELREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCUSERMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERASYNCUSERMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERASYNCUSERMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERASYNCUSERMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCUSERMODELREQUEST.fields_by_name['version']._options = None
  _TRIGGERASYNCUSERMODELREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCUSERMODELRESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCUSERMODELRESPONSE.fields_by_name['operation']._serialized_options = b'\342A\001\003'
  _TRIGGERUSERLATESTMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERUSERLATESTMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERUSERLATESTMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERUSERLATESTMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCUSERLATESTMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERASYNCUSERLATESTMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERASYNCUSERLATESTMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERASYNCUSERLATESTMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCUSERLATESTMODELRESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCUSERLATESTMODELRESPONSE.fields_by_name['operation']._serialized_options = b'\342A\001\003'
  _TRIGGERUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['name']._options = None
  _TRIGGERUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_input']._options = None
  _TRIGGERUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_input']._serialized_options = b'\342A\001\002'
  _TRIGGERUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['version']._options = None
  _TRIGGERUSERMODELBINARYFILEUPLOADREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._options = None
  _TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._serialized_options = b'\342A\001\002'
  _TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._options = None
  _TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._serialized_options = b'\342A\001\002'
  _TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE.fields_by_name['version']._options = None
  _TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _CREATEORGANIZATIONMODELREQUEST.fields_by_name['parent']._options = None
  _CREATEORGANIZATIONMODELREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\342A\001\002\372A\030\022\026api.instill.tech/Model'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['page_token']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['view']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['parent']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\342A\001\002\372A\030\022\026api.instill.tech/Model'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['show_deleted']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['filter']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['visibility']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['visibility']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['order_by']._options = None
  _LISTORGANIZATIONMODELSREQUEST.fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _GETORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _GETORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _GETORGANIZATIONMODELREQUEST.fields_by_name['view']._options = None
  _GETORGANIZATIONMODELREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _UPDATEORGANIZATIONMODELREQUEST.fields_by_name['model']._options = None
  _UPDATEORGANIZATIONMODELREQUEST.fields_by_name['model']._serialized_options = b'\342A\001\002'
  _UPDATEORGANIZATIONMODELREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEORGANIZATIONMODELREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _DELETEORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _DELETEORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _RENAMEORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _RENAMEORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _RENAMEORGANIZATIONMODELREQUEST.fields_by_name['new_model_id']._options = None
  _RENAMEORGANIZATIONMODELREQUEST.fields_by_name['new_model_id']._serialized_options = b'\342A\001\002'
  _WATCHORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _WATCHORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _WATCHORGANIZATIONMODELREQUEST.fields_by_name['version']._options = None
  _WATCHORGANIZATIONMODELREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _WATCHORGANIZATIONLATESTMODELREQUEST.fields_by_name['name']._options = None
  _WATCHORGANIZATIONLATESTMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _LISTORGANIZATIONMODELVERSIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONMODELVERSIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONMODELVERSIONSREQUEST.fields_by_name['page']._options = None
  _LISTORGANIZATIONMODELVERSIONSREQUEST.fields_by_name['page']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONMODELVERSIONSREQUEST.fields_by_name['name']._options = None
  _LISTORGANIZATIONMODELVERSIONSREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _DELETEORGANIZATIONMODELVERSIONREQUEST.fields_by_name['name']._options = None
  _DELETEORGANIZATIONMODELVERSIONREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _DELETEORGANIZATIONMODELVERSIONREQUEST.fields_by_name['version']._options = None
  _DELETEORGANIZATIONMODELVERSIONREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _TRIGGERORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERORGANIZATIONMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERORGANIZATIONMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERORGANIZATIONMODELREQUEST.fields_by_name['version']._options = None
  _TRIGGERORGANIZATIONMODELREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCORGANIZATIONMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERASYNCORGANIZATIONMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERASYNCORGANIZATIONMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERASYNCORGANIZATIONMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCORGANIZATIONMODELREQUEST.fields_by_name['version']._options = None
  _TRIGGERASYNCORGANIZATIONMODELREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCORGANIZATIONMODELRESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCORGANIZATIONMODELRESPONSE.fields_by_name['operation']._serialized_options = b'\342A\001\003'
  _TRIGGERORGANIZATIONLATESTMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERORGANIZATIONLATESTMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERORGANIZATIONLATESTMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERORGANIZATIONLATESTMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCORGANIZATIONLATESTMODELREQUEST.fields_by_name['name']._options = None
  _TRIGGERASYNCORGANIZATIONLATESTMODELREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERASYNCORGANIZATIONLATESTMODELREQUEST.fields_by_name['task_inputs']._options = None
  _TRIGGERASYNCORGANIZATIONLATESTMODELREQUEST.fields_by_name['task_inputs']._serialized_options = b'\342A\001\002'
  _TRIGGERASYNCORGANIZATIONLATESTMODELRESPONSE.fields_by_name['operation']._options = None
  _TRIGGERASYNCORGANIZATIONLATESTMODELRESPONSE.fields_by_name['operation']._serialized_options = b'\342A\001\003'
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['name']._options = None
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_input']._options = None
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['task_input']._serialized_options = b'\342A\001\002'
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['version']._options = None
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._options = None
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task']._serialized_options = b'\342A\001\002'
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._options = None
  _TRIGGERORGANIZATIONMODELBINARYFILEUPLOADRESPONSE.fields_by_name['task_outputs']._serialized_options = b'\342A\001\002'
  _GETMODELOPERATIONREQUEST.fields_by_name['operation_id']._options = None
  _GETMODELOPERATIONREQUEST.fields_by_name['operation_id']._serialized_options = b'\342A\001\002'
  _GETMODELOPERATIONREQUEST.fields_by_name['view']._options = None
  _GETMODELOPERATIONREQUEST.fields_by_name['view']._serialized_options = b'\030\001\342A\001\001'
  _GETUSERLATESTMODELOPERATIONREQUEST.fields_by_name['name']._options = None
  _GETUSERLATESTMODELOPERATIONREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _GETUSERLATESTMODELOPERATIONREQUEST.fields_by_name['view']._options = None
  _GETUSERLATESTMODELOPERATIONREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _GETORGANIZATIONLATESTMODELOPERATIONREQUEST.fields_by_name['name']._options = None
  _GETORGANIZATIONLATESTMODELOPERATIONREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _GETORGANIZATIONLATESTMODELOPERATIONREQUEST.fields_by_name['view']._options = None
  _GETORGANIZATIONLATESTMODELOPERATIONREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTMODELSADMINREQUEST.fields_by_name['page_size']._options = None
  _LISTMODELSADMINREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTMODELSADMINREQUEST.fields_by_name['page_token']._options = None
  _LISTMODELSADMINREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTMODELSADMINREQUEST.fields_by_name['view']._options = None
  _LISTMODELSADMINREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTMODELSADMINREQUEST.fields_by_name['show_deleted']._options = None
  _LISTMODELSADMINREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _LISTMODELSADMINREQUEST.fields_by_name['filter']._options = None
  _LISTMODELSADMINREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LOOKUPMODELADMINREQUEST.fields_by_name['permalink']._options = None
  _LOOKUPMODELADMINREQUEST.fields_by_name['permalink']._serialized_options = b'\342A\001\002'
  _LOOKUPMODELADMINREQUEST.fields_by_name['view']._options = None
  _LOOKUPMODELADMINREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _DEPLOYUSERMODELADMINREQUEST.fields_by_name['name']._options = None
  _DEPLOYUSERMODELADMINREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _DEPLOYUSERMODELADMINREQUEST.fields_by_name['version']._options = None
  _DEPLOYUSERMODELADMINREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _DEPLOYUSERMODELADMINREQUEST.fields_by_name['digest']._options = None
  _DEPLOYUSERMODELADMINREQUEST.fields_by_name['digest']._serialized_options = b'\342A\001\001'
  _DEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['name']._options = None
  _DEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _DEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['version']._options = None
  _DEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _DEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['digest']._options = None
  _DEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['digest']._serialized_options = b'\342A\001\001'
  _UNDEPLOYUSERMODELADMINREQUEST.fields_by_name['name']._options = None
  _UNDEPLOYUSERMODELADMINREQUEST.fields_by_name['name']._serialized_options = b'\222A\025\312>\022\372\002\017user_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _UNDEPLOYUSERMODELADMINREQUEST.fields_by_name['version']._options = None
  _UNDEPLOYUSERMODELADMINREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _UNDEPLOYUSERMODELADMINREQUEST.fields_by_name['digest']._options = None
  _UNDEPLOYUSERMODELADMINREQUEST.fields_by_name['digest']._serialized_options = b'\342A\001\001'
  _UNDEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['name']._options = None
  _UNDEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['name']._serialized_options = b'\222A\035\312>\032\372\002\027organization_model_name\342A\001\002\372A\030\n\026api.instill.tech/Model'
  _UNDEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['version']._options = None
  _UNDEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['version']._serialized_options = b'\342A\001\002'
  _UNDEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['digest']._options = None
  _UNDEPLOYORGANIZATIONMODELADMINREQUEST.fields_by_name['digest']._serialized_options = b'\342A\001\001'
  _globals['_STATE']._serialized_start=25349
  _globals['_STATE']._serialized_end=25488
  _globals['_LIVENESSREQUEST']._serialized_start=1053
  _globals['_LIVENESSREQUEST']._serialized_end=1203
  _globals['_LIVENESSRESPONSE']._serialized_start=1205
  _globals['_LIVENESSRESPONSE']._serialized_end=1323
  _globals['_READINESSREQUEST']._serialized_start=1326
  _globals['_READINESSREQUEST']._serialized_end=1477
  _globals['_READINESSRESPONSE']._serialized_start=1479
  _globals['_READINESSRESPONSE']._serialized_end=1598
  _globals['_REGION']._serialized_start=1600
  _globals['_REGION']._serialized_end=1669
  _globals['_MODELVERSION']._serialized_start=1672
  _globals['_MODELVERSION']._serialized_end=1898
  _globals['_MODEL']._serialized_start=1901
  _globals['_MODEL']._serialized_end=3616
  _globals['_MODEL_VISIBILITY']._serialized_start=3329
  _globals['_MODEL_VISIBILITY']._serialized_end=3416
  _globals['_LISTMODELSREQUEST']._serialized_start=3619
  _globals['_LISTMODELSREQUEST']._serialized_end=4073
  _globals['_LISTMODELSRESPONSE']._serialized_start=4076
  _globals['_LISTMODELSRESPONSE']._serialized_end=4219
  _globals['_LOOKUPMODELREQUEST']._serialized_start=4221
  _globals['_LOOKUPMODELREQUEST']._serialized_end=4344
  _globals['_LOOKUPMODELRESPONSE']._serialized_start=4346
  _globals['_LOOKUPMODELRESPONSE']._serialized_end=4417
  _globals['_LISTNAMESPACEMODELSREQUEST']._serialized_start=4420
  _globals['_LISTNAMESPACEMODELSREQUEST']._serialized_end=4924
  _globals['_LISTNAMESPACEMODELSRESPONSE']._serialized_start=4927
  _globals['_LISTNAMESPACEMODELSRESPONSE']._serialized_end=5079
  _globals['_CREATENAMESPACEMODELREQUEST']._serialized_start=5081
  _globals['_CREATENAMESPACEMODELREQUEST']._serialized_end=5201
  _globals['_CREATENAMESPACEMODELRESPONSE']._serialized_start=5203
  _globals['_CREATENAMESPACEMODELRESPONSE']._serialized_end=5283
  _globals['_GETNAMESPACEMODELREQUEST']._serialized_start=5286
  _globals['_GETNAMESPACEMODELREQUEST']._serialized_end=5453
  _globals['_GETNAMESPACEMODELRESPONSE']._serialized_start=5455
  _globals['_GETNAMESPACEMODELRESPONSE']._serialized_end=5532
  _globals['_UPDATENAMESPACEMODELREQUEST']._serialized_start=5535
  _globals['_UPDATENAMESPACEMODELREQUEST']._serialized_end=5761
  _globals['_UPDATENAMESPACEMODELRESPONSE']._serialized_start=5763
  _globals['_UPDATENAMESPACEMODELRESPONSE']._serialized_end=5843
  _globals['_DELETENAMESPACEMODELREQUEST']._serialized_start=5845
  _globals['_DELETENAMESPACEMODELREQUEST']._serialized_end=5948
  _globals['_DELETENAMESPACEMODELRESPONSE']._serialized_start=5950
  _globals['_DELETENAMESPACEMODELRESPONSE']._serialized_end=5980
  _globals['_RENAMENAMESPACEMODELREQUEST']._serialized_start=5983
  _globals['_RENAMENAMESPACEMODELREQUEST']._serialized_end=6126
  _globals['_RENAMENAMESPACEMODELRESPONSE']._serialized_start=6128
  _globals['_RENAMENAMESPACEMODELRESPONSE']._serialized_end=6208
  _globals['_WATCHNAMESPACEMODELREQUEST']._serialized_start=6211
  _globals['_WATCHNAMESPACEMODELREQUEST']._serialized_end=6345
  _globals['_WATCHNAMESPACEMODELRESPONSE']._serialized_start=6347
  _globals['_WATCHNAMESPACEMODELRESPONSE']._serialized_end=6458
  _globals['_WATCHNAMESPACELATESTMODELREQUEST']._serialized_start=6460
  _globals['_WATCHNAMESPACELATESTMODELREQUEST']._serialized_end=6568
  _globals['_WATCHNAMESPACELATESTMODELRESPONSE']._serialized_start=6570
  _globals['_WATCHNAMESPACELATESTMODELRESPONSE']._serialized_end=6687
  _globals['_LISTNAMESPACEMODELVERSIONSREQUEST']._serialized_start=6690
  _globals['_LISTNAMESPACEMODELVERSIONSREQUEST']._serialized_end=6893
  _globals['_LISTNAMESPACEMODELVERSIONSRESPONSE']._serialized_start=6896
  _globals['_LISTNAMESPACEMODELVERSIONSRESPONSE']._serialized_end=7099
  _globals['_DELETENAMESPACEMODELVERSIONREQUEST']._serialized_start=7102
  _globals['_DELETENAMESPACEMODELVERSIONREQUEST']._serialized_end=7244
  _globals['_DELETENAMESPACEMODELVERSIONRESPONSE']._serialized_start=7246
  _globals['_DELETENAMESPACEMODELVERSIONRESPONSE']._serialized_end=7283
  _globals['_TRIGGERNAMESPACEMODELREQUEST']._serialized_start=7286
  _globals['_TRIGGERNAMESPACEMODELREQUEST']._serialized_end=7493
  _globals['_TRIGGERNAMESPACEMODELRESPONSE']._serialized_start=7496
  _globals['_TRIGGERNAMESPACEMODELRESPONSE']._serialized_end=7642
  _globals['_TRIGGERASYNCNAMESPACEMODELREQUEST']._serialized_start=7645
  _globals['_TRIGGERASYNCNAMESPACEMODELREQUEST']._serialized_end=7857
  _globals['_TRIGGERASYNCNAMESPACEMODELRESPONSE']._serialized_start=7859
  _globals['_TRIGGERASYNCNAMESPACEMODELRESPONSE']._serialized_end=7962
  _globals['_TRIGGERNAMESPACELATESTMODELREQUEST']._serialized_start=7965
  _globals['_TRIGGERNAMESPACELATESTMODELREQUEST']._serialized_end=8146
  _globals['_TRIGGERNAMESPACELATESTMODELRESPONSE']._serialized_start=8149
  _globals['_TRIGGERNAMESPACELATESTMODELRESPONSE']._serialized_end=8301
  _globals['_TRIGGERASYNCNAMESPACELATESTMODELREQUEST']._serialized_start=8304
  _globals['_TRIGGERASYNCNAMESPACELATESTMODELREQUEST']._serialized_end=8490
  _globals['_TRIGGERASYNCNAMESPACELATESTMODELRESPONSE']._serialized_start=8492
  _globals['_TRIGGERASYNCNAMESPACELATESTMODELRESPONSE']._serialized_end=8601
  _globals['_TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST']._serialized_start=8604
  _globals['_TRIGGERNAMESPACEMODELBINARYFILEUPLOADREQUEST']._serialized_end=8831
  _globals['_TRIGGERNAMESPACEMODELBINARYFILEUPLOADRESPONSE']._serialized_start=8834
  _globals['_TRIGGERNAMESPACEMODELBINARYFILEUPLOADRESPONSE']._serialized_end=9040
  _globals['_TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADREQUEST']._serialized_start=9043
  _globals['_TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADREQUEST']._serialized_end=9244
  _globals['_TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADRESPONSE']._serialized_start=9247
  _globals['_TRIGGERNAMESPACELATESTMODELBINARYFILEUPLOADRESPONSE']._serialized_end=9427
  _globals['_GETNAMESPACELATESTMODELOPERATIONREQUEST']._serialized_start=9430
  _globals['_GETNAMESPACELATESTMODELOPERATIONREQUEST']._serialized_end=9612
  _globals['_GETNAMESPACELATESTMODELOPERATIONRESPONSE']._serialized_start=9614
  _globals['_GETNAMESPACELATESTMODELOPERATIONRESPONSE']._serialized_end=9717
  _globals['_DEPLOYNAMESPACEMODELADMINREQUEST']._serialized_start=9720
  _globals['_DEPLOYNAMESPACEMODELADMINREQUEST']._serialized_end=9890
  _globals['_DEPLOYNAMESPACEMODELADMINRESPONSE']._serialized_start=9892
  _globals['_DEPLOYNAMESPACEMODELADMINRESPONSE']._serialized_end=9933
  _globals['_UNDEPLOYNAMESPACEMODELADMINREQUEST']._serialized_start=9936
  _globals['_UNDEPLOYNAMESPACEMODELADMINREQUEST']._serialized_end=10108
  _globals['_UNDEPLOYNAMESPACEMODELADMINRESPONSE']._serialized_start=10110
  _globals['_UNDEPLOYNAMESPACEMODELADMINRESPONSE']._serialized_end=10153
  _globals['_CREATEUSERMODELREQUEST']._serialized_start=10156
  _globals['_CREATEUSERMODELREQUEST']._serialized_end=10305
  _globals['_CREATEUSERMODELRESPONSE']._serialized_start=10307
  _globals['_CREATEUSERMODELRESPONSE']._serialized_end=10382
  _globals['_LISTUSERMODELSREQUEST']._serialized_start=10385
  _globals['_LISTUSERMODELSREQUEST']._serialized_end=10918
  _globals['_LISTUSERMODELSRESPONSE']._serialized_start=10921
  _globals['_LISTUSERMODELSRESPONSE']._serialized_end=11068
  _globals['_GETUSERMODELREQUEST']._serialized_start=11071
  _globals['_GETUSERMODELREQUEST']._serialized_end=11236
  _globals['_GETUSERMODELRESPONSE']._serialized_start=11238
  _globals['_GETUSERMODELRESPONSE']._serialized_end=11310
  _globals['_UPDATEUSERMODELREQUEST']._serialized_start=11313
  _globals['_UPDATEUSERMODELREQUEST']._serialized_end=11460
  _globals['_UPDATEUSERMODELRESPONSE']._serialized_start=11462
  _globals['_UPDATEUSERMODELRESPONSE']._serialized_end=11537
  _globals['_DELETEUSERMODELREQUEST']._serialized_start=11539
  _globals['_DELETEUSERMODELREQUEST']._serialized_end=11640
  _globals['_DELETEUSERMODELRESPONSE']._serialized_start=11642
  _globals['_DELETEUSERMODELRESPONSE']._serialized_end=11667
  _globals['_RENAMEUSERMODELREQUEST']._serialized_start=11670
  _globals['_RENAMEUSERMODELREQUEST']._serialized_end=11811
  _globals['_RENAMEUSERMODELRESPONSE']._serialized_start=11813
  _globals['_RENAMEUSERMODELRESPONSE']._serialized_end=11888
  _globals['_WATCHUSERMODELREQUEST']._serialized_start=11891
  _globals['_WATCHUSERMODELREQUEST']._serialized_end=12023
  _globals['_WATCHUSERMODELRESPONSE']._serialized_start=12025
  _globals['_WATCHUSERMODELRESPONSE']._serialized_end=12131
  _globals['_WATCHUSERLATESTMODELREQUEST']._serialized_start=12133
  _globals['_WATCHUSERLATESTMODELREQUEST']._serialized_end=12239
  _globals['_WATCHUSERLATESTMODELRESPONSE']._serialized_start=12241
  _globals['_WATCHUSERLATESTMODELRESPONSE']._serialized_end=12353
  _globals['_LISTUSERMODELVERSIONSREQUEST']._serialized_start=12356
  _globals['_LISTUSERMODELVERSIONSREQUEST']._serialized_end=12557
  _globals['_LISTUSERMODELVERSIONSRESPONSE']._serialized_start=12560
  _globals['_LISTUSERMODELVERSIONSRESPONSE']._serialized_end=12734
  _globals['_DELETEUSERMODELVERSIONREQUEST']._serialized_start=12737
  _globals['_DELETEUSERMODELVERSIONREQUEST']._serialized_end=12877
  _globals['_DELETEUSERMODELVERSIONRESPONSE']._serialized_start=12879
  _globals['_DELETEUSERMODELVERSIONRESPONSE']._serialized_end=12911
  _globals['_TASKINPUT']._serialized_start=12914
  _globals['_TASKINPUT']._serialized_end=13938
  _globals['_TASKINPUTSTREAM']._serialized_start=13941
  _globals['_TASKINPUTSTREAM']._serialized_end=15007
  _globals['_TASKOUTPUT']._serialized_start=15010
  _globals['_TASKOUTPUT']._serialized_end=16120
  _globals['_TRIGGERUSERMODELREQUEST']._serialized_start=16123
  _globals['_TRIGGERUSERMODELREQUEST']._serialized_end=16328
  _globals['_TRIGGERUSERMODELRESPONSE']._serialized_start=16331
  _globals['_TRIGGERUSERMODELRESPONSE']._serialized_end=16472
  _globals['_TRIGGERASYNCUSERMODELREQUEST']._serialized_start=16475
  _globals['_TRIGGERASYNCUSERMODELREQUEST']._serialized_end=16685
  _globals['_TRIGGERASYNCUSERMODELRESPONSE']._serialized_start=16687
  _globals['_TRIGGERASYNCUSERMODELRESPONSE']._serialized_end=16785
  _globals['_TRIGGERUSERLATESTMODELREQUEST']._serialized_start=16788
  _globals['_TRIGGERUSERLATESTMODELREQUEST']._serialized_end=16967
  _globals['_TRIGGERUSERLATESTMODELRESPONSE']._serialized_start=16970
  _globals['_TRIGGERUSERLATESTMODELRESPONSE']._serialized_end=17117
  _globals['_TRIGGERASYNCUSERLATESTMODELREQUEST']._serialized_start=17120
  _globals['_TRIGGERASYNCUSERLATESTMODELREQUEST']._serialized_end=17304
  _globals['_TRIGGERASYNCUSERLATESTMODELRESPONSE']._serialized_start=17306
  _globals['_TRIGGERASYNCUSERLATESTMODELRESPONSE']._serialized_end=17410
  _globals['_TRIGGERUSERMODELBINARYFILEUPLOADREQUEST']._serialized_start=17413
  _globals['_TRIGGERUSERMODELBINARYFILEUPLOADREQUEST']._serialized_end=17638
  _globals['_TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE']._serialized_start=17641
  _globals['_TRIGGERUSERMODELBINARYFILEUPLOADRESPONSE']._serialized_end=17842
  _globals['_CREATEORGANIZATIONMODELREQUEST']._serialized_start=17845
  _globals['_CREATEORGANIZATIONMODELREQUEST']._serialized_end=18010
  _globals['_CREATEORGANIZATIONMODELRESPONSE']._serialized_start=18012
  _globals['_CREATEORGANIZATIONMODELRESPONSE']._serialized_end=18095
  _globals['_LISTORGANIZATIONMODELSREQUEST']._serialized_start=18098
  _globals['_LISTORGANIZATIONMODELSREQUEST']._serialized_end=18647
  _globals['_LISTORGANIZATIONMODELSRESPONSE']._serialized_start=18650
  _globals['_LISTORGANIZATIONMODELSRESPONSE']._serialized_end=18805
  _globals['_GETORGANIZATIONMODELREQUEST']._serialized_start=18808
  _globals['_GETORGANIZATIONMODELREQUEST']._serialized_end=18989
  _globals['_GETORGANIZATIONMODELRESPONSE']._serialized_start=18991
  _globals['_GETORGANIZATIONMODELRESPONSE']._serialized_end=19071
  _globals['_UPDATEORGANIZATIONMODELREQUEST']._serialized_start=19074
  _globals['_UPDATEORGANIZATIONMODELREQUEST']._serialized_end=19229
  _globals['_UPDATEORGANIZATIONMODELRESPONSE']._serialized_start=19231
  _globals['_UPDATEORGANIZATIONMODELRESPONSE']._serialized_end=19314
  _globals['_DELETEORGANIZATIONMODELREQUEST']._serialized_start=19316
  _globals['_DELETEORGANIZATIONMODELREQUEST']._serialized_end=19433
  _globals['_DELETEORGANIZATIONMODELRESPONSE']._serialized_start=19435
  _globals['_DELETEORGANIZATIONMODELRESPONSE']._serialized_end=19468
  _globals['_RENAMEORGANIZATIONMODELREQUEST']._serialized_start=19471
  _globals['_RENAMEORGANIZATIONMODELREQUEST']._serialized_end=19628
  _globals['_RENAMEORGANIZATIONMODELRESPONSE']._serialized_start=19630
  _globals['_RENAMEORGANIZATIONMODELRESPONSE']._serialized_end=19713
  _globals['_WATCHORGANIZATIONMODELREQUEST']._serialized_start=19716
  _globals['_WATCHORGANIZATIONMODELREQUEST']._serialized_end=19864
  _globals['_WATCHORGANIZATIONMODELRESPONSE']._serialized_start=19866
  _globals['_WATCHORGANIZATIONMODELRESPONSE']._serialized_end=19980
  _globals['_WATCHORGANIZATIONLATESTMODELREQUEST']._serialized_start=19982
  _globals['_WATCHORGANIZATIONLATESTMODELREQUEST']._serialized_end=20104
  _globals['_WATCHORGANIZATIONLATESTMODELRESPONSE']._serialized_start=20106
  _globals['_WATCHORGANIZATIONLATESTMODELRESPONSE']._serialized_end=20226
  _globals['_LISTORGANIZATIONMODELVERSIONSREQUEST']._serialized_start=20229
  _globals['_LISTORGANIZATIONMODELVERSIONSREQUEST']._serialized_end=20446
  _globals['_LISTORGANIZATIONMODELVERSIONSRESPONSE']._serialized_start=20449
  _globals['_LISTORGANIZATIONMODELVERSIONSRESPONSE']._serialized_end=20631
  _globals['_DELETEORGANIZATIONMODELVERSIONREQUEST']._serialized_start=20634
  _globals['_DELETEORGANIZATIONMODELVERSIONREQUEST']._serialized_end=20790
  _globals['_DELETEORGANIZATIONMODELVERSIONRESPONSE']._serialized_start=20792
  _globals['_DELETEORGANIZATIONMODELVERSIONRESPONSE']._serialized_end=20832
  _globals['_TRIGGERORGANIZATIONMODELREQUEST']._serialized_start=20835
  _globals['_TRIGGERORGANIZATIONMODELREQUEST']._serialized_end=21056
  _globals['_TRIGGERORGANIZATIONMODELRESPONSE']._serialized_start=21059
  _globals['_TRIGGERORGANIZATIONMODELRESPONSE']._serialized_end=21208
  _globals['_TRIGGERASYNCORGANIZATIONMODELREQUEST']._serialized_start=21211
  _globals['_TRIGGERASYNCORGANIZATIONMODELREQUEST']._serialized_end=21437
  _globals['_TRIGGERASYNCORGANIZATIONMODELRESPONSE']._serialized_start=21439
  _globals['_TRIGGERASYNCORGANIZATIONMODELRESPONSE']._serialized_end=21545
  _globals['_TRIGGERORGANIZATIONLATESTMODELREQUEST']._serialized_start=21548
  _globals['_TRIGGERORGANIZATIONLATESTMODELREQUEST']._serialized_end=21743
  _globals['_TRIGGERORGANIZATIONLATESTMODELRESPONSE']._serialized_start=21746
  _globals['_TRIGGERORGANIZATIONLATESTMODELRESPONSE']._serialized_end=21901
  _globals['_TRIGGERASYNCORGANIZATIONLATESTMODELREQUEST']._serialized_start=21904
  _globals['_TRIGGERASYNCORGANIZATIONLATESTMODELREQUEST']._serialized_end=22104
  _globals['_TRIGGERASYNCORGANIZATIONLATESTMODELRESPONSE']._serialized_start=22106
  _globals['_TRIGGERASYNCORGANIZATIONLATESTMODELRESPONSE']._serialized_end=22218
  _globals['_TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST']._serialized_start=22221
  _globals['_TRIGGERORGANIZATIONMODELBINARYFILEUPLOADREQUEST']._serialized_end=22462
  _globals['_TRIGGERORGANIZATIONMODELBINARYFILEUPLOADRESPONSE']._serialized_start=22465
  _globals['_TRIGGERORGANIZATIONMODELBINARYFILEUPLOADRESPONSE']._serialized_end=22642
  _globals['_GETMODELOPERATIONREQUEST']._serialized_start=22645
  _globals['_GETMODELOPERATIONREQUEST']._serialized_end=22781
  _globals['_GETMODELOPERATIONRESPONSE']._serialized_start=22783
  _globals['_GETMODELOPERATIONRESPONSE']._serialized_end=22871
  _globals['_LATESTOPERATION']._serialized_start=22874
  _globals['_LATESTOPERATION']._serialized_end=23060
  _globals['_GETUSERLATESTMODELOPERATIONREQUEST']._serialized_start=23063
  _globals['_GETUSERLATESTMODELOPERATIONREQUEST']._serialized_end=23243
  _globals['_GETUSERLATESTMODELOPERATIONRESPONSE']._serialized_start=23245
  _globals['_GETUSERLATESTMODELOPERATIONRESPONSE']._serialized_end=23343
  _globals['_GETORGANIZATIONLATESTMODELOPERATIONREQUEST']._serialized_start=23346
  _globals['_GETORGANIZATIONLATESTMODELOPERATIONREQUEST']._serialized_end=23542
  _globals['_GETORGANIZATIONLATESTMODELOPERATIONRESPONSE']._serialized_start=23544
  _globals['_GETORGANIZATIONLATESTMODELOPERATIONRESPONSE']._serialized_end=23650
  _globals['_LISTAVAILABLEREGIONSREQUEST']._serialized_start=23652
  _globals['_LISTAVAILABLEREGIONSREQUEST']._serialized_end=23681
  _globals['_LISTAVAILABLEREGIONSRESPONSE']._serialized_start=23683
  _globals['_LISTAVAILABLEREGIONSRESPONSE']._serialized_end=23768
  _globals['_LISTMODELSADMINREQUEST']._serialized_start=23771
  _globals['_LISTMODELSADMINREQUEST']._serialized_end=24082
  _globals['_LISTMODELSADMINRESPONSE']._serialized_start=24085
  _globals['_LISTMODELSADMINRESPONSE']._serialized_end=24233
  _globals['_LOOKUPMODELADMINREQUEST']._serialized_start=24236
  _globals['_LOOKUPMODELADMINREQUEST']._serialized_end=24364
  _globals['_LOOKUPMODELADMINRESPONSE']._serialized_start=24366
  _globals['_LOOKUPMODELADMINRESPONSE']._serialized_end=24442
  _globals['_DEPLOYUSERMODELADMINREQUEST']._serialized_start=24445
  _globals['_DEPLOYUSERMODELADMINREQUEST']._serialized_end=24619
  _globals['_DEPLOYUSERMODELADMINRESPONSE']._serialized_start=24621
  _globals['_DEPLOYUSERMODELADMINRESPONSE']._serialized_end=24657
  _globals['_DEPLOYORGANIZATIONMODELADMINREQUEST']._serialized_start=24660
  _globals['_DEPLOYORGANIZATIONMODELADMINREQUEST']._serialized_end=24850
  _globals['_DEPLOYORGANIZATIONMODELADMINRESPONSE']._serialized_start=24852
  _globals['_DEPLOYORGANIZATIONMODELADMINRESPONSE']._serialized_end=24890
  _globals['_UNDEPLOYUSERMODELADMINREQUEST']._serialized_start=24893
  _globals['_UNDEPLOYUSERMODELADMINREQUEST']._serialized_end=25069
  _globals['_UNDEPLOYUSERMODELADMINRESPONSE']._serialized_start=25071
  _globals['_UNDEPLOYUSERMODELADMINRESPONSE']._serialized_end=25109
  _globals['_UNDEPLOYORGANIZATIONMODELADMINREQUEST']._serialized_start=25112
  _globals['_UNDEPLOYORGANIZATIONMODELADMINREQUEST']._serialized_end=25304
  _globals['_UNDEPLOYORGANIZATIONMODELADMINRESPONSE']._serialized_start=25306
  _globals['_UNDEPLOYORGANIZATIONMODELADMINRESPONSE']._serialized_end=25346
# @@protoc_insertion_point(module_scope)
